@@ -1,6 +1,6 @@
 package Class::Meta::AccessorBuilder;
 
-# $Id: AccessorBuilder.pm 1071 2005-01-07 19:45:54Z theory $
+# $Id: AccessorBuilder.pm 1462 2005-04-04 03:36:04Z theory $
 
 =head1 NAME
 
@@ -102,7 +102,7 @@ not be reflected in other threads.
 
 Any attributes that have their C<view> attribute set to Class::Meta::Private
 or Class::Meta::Protected get additional validation installed to ensure that
-they're truly private and protected. This includes when they are set via
+they're truly private or protected. This includes when they are set via
 parameters to constructors generated by Class::Meta. The validation is
 performed by checking the caller of the accessors, and throwing an exception
 when the caller isn't the class that owns the attribute (for private
@@ -191,7 +191,7 @@ be used in the set acccessor (mutator) to validate new attribute values.
 
 use strict;
 use Class::Meta;
-our $VERSION = "0.46";
+our $VERSION = "0.47";
 
 sub build_attr_get {
     UNIVERSAL::can($_[0]->package, $_[0]->name);
@@ -350,6 +350,23 @@ sub build {
                unless $caller eq $pkg;
              goto &$real_sub;
          };
+    } elsif ($attr->view == Class::Meta::TRUSTED) {
+        my $real_sub = $sub;
+        # XXX Should we have an accessor for this?
+        my $trusted = $attr->class->{trusted};
+        $sub = sub {
+             my $caller = caller;
+             # Circumvent generated constructors.
+             for (my $i = 1; $caller eq 'Class::Meta::Constructor'; $i++) {
+                 $caller = caller($i);
+             }
+
+             goto &$real_sub if $caller eq $pkg;
+             for my $pack (@{$trusted}) {
+                 goto &$real_sub if UNIVERSAL::isa($caller, $pack);
+             }
+             $attr->class->handle_error("$name is a trusted attribute of $pkg");
+         };
     }
 
     # Install the accessor.
@@ -362,8 +379,8 @@ __END__
 
 =head1 BUGS
 
-Please report all bugs via the CPAN Request Tracker at
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Meta>.
+Please send bug reports to <bug-class-meta@rt.cpan.org> or report them via the
+CPAN Request Tracker at L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Meta>.
 
 =head1 AUTHOR
 
@@ -401,7 +418,7 @@ generated accessors.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2002-2004, David Wheeler. All Rights Reserved.
+Copyright (c) 2002-2005, David Wheeler. All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
